sequencetools.map_sequence_elements_to_canonic_tuples
=====================================================

.. autofunction:: abjad.tools.sequencetools.map_sequence_elements_to_canonic_tuples.map_sequence_elements_to_canonic_tuples
